---
delivery_guarantee: "best_effort"
component_title: "GCP Stackdriver Logging"
description: "The Vector `gcp_stackdriver_logging` sink batches [`log`](#log) events to Google Cloud Platform's Stackdriver Logging service via the REST Interface."
event_types: ["log"]
issues_url: https://github.com/timberio/vector/issues?q=is%3Aopen+is%3Aissue+label%3A%22sink%3A+gcp_stackdriver_logging%22
min_version: null
operating_systems: ["Linux","MacOS","Windows"]
service_name: "GCP Stackdriver Logging"
sidebar_label: "gcp_stackdriver_logging|[\"log\"]"
source_url: https://github.com/timberio/vector/blob/master/src/sinks/gcp/stackdriver_logging.rs
status: "beta"
title: "GCP Stackdriver Logging Sink"
unsupported_operating_systems: []
---

The Vector `gcp_stackdriver_logging` sink [batches](#buffers--batches) [`log`][docs.data-model.log] events to [Google Cloud Platform's Stackdriver Logging service][urls.gcp_stackdriver_logging] via the [REST Interface][urls.gcp_stackdriver_logging_rest].

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/reference/sinks/gcp_stackdriver_logging.md.erb
-->

## Configuration

import Tabs from '@theme/Tabs';

<Tabs
  block={true}
  defaultValue="common"
  values={[{"label":"Common","value":"common"},{"label":"Advanced","value":"advanced"}]}>

import TabItem from '@theme/TabItem';

<TabItem value="common">

import CodeHeader from '@site/src/components/CodeHeader';

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sinks.my_sink_id]
  # REQUIRED
  type = "gcp_stackdriver_logging" # must be: "gcp_stackdriver_logging"
  inputs = ["my-source-id"] # example
  credentials_path = "/path/to/credentials.json" # example
  log_id = "vector-logs" # example
  project_id = "vector-123456" # example

  # OPTIONAL
  healthcheck = true # default
```

</TabItem>
<TabItem value="advanced">

<CodeHeader fileName="vector.toml" learnMoreUrl="/docs/setup/configuration/"/ >

```toml
[sinks.my_sink_id]
  # REQUIRED - General
  type = "gcp_stackdriver_logging" # must be: "gcp_stackdriver_logging"
  inputs = ["my-source-id"] # example
  credentials_path = "/path/to/credentials.json" # example
  log_id = "vector-logs" # example
  project_id = "vector-123456" # example

  # OPTIONAL - General
  billing_account_id = "012345-6789AB-CDEF01" # example, no default
  folder_id = "My Folder" # example, no default
  healthcheck = true # default
  organization_id = "622418129737" # example, no default

  # OPTIONAL - Batch
  [sinks.my_sink_id.batch]
    max_size = 5242880 # default, bytes
    timeout_secs = 1 # default, seconds

  # OPTIONAL - Buffer
  [sinks.my_sink_id.buffer]
    # OPTIONAL
    type = "memory" # default, enum
    max_events = 500 # default, events, relevant when type = "memory"
    when_full = "block" # default, enum

    # REQUIRED
    max_size = 104900000 # example, bytes, relevant when type = "disk"

  # OPTIONAL - Request
  [sinks.my_sink_id.request]
    in_flight_limit = 5 # default, requests
    rate_limit_duration_secs = 1 # default, seconds
    rate_limit_num = 1000 # default
    retry_attempts = -1 # default
    retry_initial_backoff_secs = 1 # default, seconds
    retry_max_duration_secs = 10 # default, seconds
    timeout_secs = 60 # default, seconds

  # OPTIONAL - Resource
  [sinks.my_sink_id.resource]
    # REQUIRED
    type = "global" # example

    # OPTIONAL
    projectId = "vector-123456" # example
    zone = "Twilight" # example

  # OPTIONAL - Tls
  [sinks.my_sink_id.tls]
    ca_path = "/path/to/certificate_authority.crt" # example, no default
    crt_path = "/path/to/host_certificate.crt" # example, no default
    key_pass = "${KEY_PASS_ENV_VAR}" # example, no default
    key_path = "/path/to/host_certificate.key" # example, no default
    verify_certificate = true # default
    verify_hostname = true # default
```

</TabItem>
</Tabs>

## Options

import Fields from '@site/src/components/Fields';

import Field from '@site/src/components/Field';

<Fields filters={true}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"batch"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### batch

Configures the sink batching behavior.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={5242880}
  enumValues={null}
  examples={[5242880]}
  groups={[]}
  name={"max_size"}
  path={"batch"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

#### max_size

The maximum size of a batch, in bytes, before it is flushed. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


<Field
  common={true}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"timeout_secs"}
  path={"batch"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### timeout_secs

The maximum age of a batch before it is flushed. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


</Fields>

</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["012345-6789AB-CDEF01"]}
  groups={[]}
  name={"billing_account_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### billing_account_id

The billing account ID to which to publish logs.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or [`project_id`](#project_id) must be set.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"buffer"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### buffer

Configures the sink specific buffer behavior.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={500}
  enumValues={null}
  examples={[500]}
  groups={[]}
  name={"max_events"}
  path={"buffer"}
  relevantWhen={{"type":"memory"}}
  required={true}
  templateable={false}
  type={"int"}
  unit={"events"}
  >

#### max_events

The maximum number of [events][docs.data-model] allowed in the buffer.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={[104900000]}
  groups={[]}
  name={"max_size"}
  path={"buffer"}
  relevantWhen={{"type":"disk"}}
  required={true}
  templateable={false}
  type={"int"}
  unit={"bytes"}
  >

#### max_size

The maximum size of the buffer on the disk. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


<Field
  common={true}
  defaultValue={"memory"}
  enumValues={{"memory":"Stores the sink's buffer in memory. This is more performant, but less durable. Data will be lost if Vector is restarted forcefully.","disk":"Stores the sink's buffer on disk. This is less performant, but durable. Data will not be lost between restarts."}}
  examples={["memory","disk"]}
  groups={[]}
  name={"type"}
  path={"buffer"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### type

The buffer's type and storage mechanism.


</Field>


<Field
  common={false}
  defaultValue={"block"}
  enumValues={{"block":"Applies back pressure when the buffer is full. This prevents data loss, but will cause data to pile up on the edge.","drop_newest":"Drops new data as it's received. This data is lost. This should be used when performance is the highest priority."}}
  examples={["block","drop_newest"]}
  groups={[]}
  name={"when_full"}
  path={"buffer"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### when_full

The behavior when the buffer becomes full.


</Field>


</Fields>

</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/credentials.json"]}
  groups={[]}
  name={"credentials_path"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### credentials_path

The filename for a Google Cloud service account credentials JSON file used to authenticate access to the Stackdriver Logging API. If this is unset, Vector checks the `$GOOGLE_APPLICATION_CREDENTIALS` environment variable for a filename. See [GCP Authentication](#gcp-authentication) for more info.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["My Folder"]}
  groups={[]}
  name={"folder_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### folder_id

The folder ID to which to publish logs.
See the [Google Cloud Platform folder documentation][urls.gcp_folders] for more details.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or [`project_id`](#project_id) must be set.


</Field>


<Field
  common={true}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"healthcheck"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  >

### healthcheck

Enables/disables the sink healthcheck upon start. See [Health Checks](#health-checks) for more info.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["vector-logs"]}
  groups={[]}
  name={"log_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### log_id

The log ID to which to publish logs. This is a name you create to identify this log stream.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["622418129737"]}
  groups={[]}
  name={"organization_id"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### organization_id

The organization ID to which to publish logs. This would be the identifier assigned to your organization on Google Cloud Platform.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or [`project_id`](#project_id) must be set.


</Field>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["vector-123456"]}
  groups={[]}
  name={"project_id"}
  path={null}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

### project_id

The project ID to which to publish logs. See the [Google Cloud Platform project management documentation][urls.gcp_projects] for more details.

Exactly one of [`billing_account_id`](#billing_account_id), [`folder_id`](#folder_id), [`organization_id`](#organization_id), or [`project_id`](#project_id) must be set.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"request"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### request

Configures the sink request behavior.

<Fields filters={false}>


<Field
  common={false}
  defaultValue={5}
  enumValues={null}
  examples={[5]}
  groups={[]}
  name={"in_flight_limit"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"requests"}
  >

#### in_flight_limit

The maximum number of in-flight requests allowed at any given time. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"rate_limit_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### rate_limit_duration_secs

The time window, in seconds, used for the [`rate_limit_num`](#rate_limit_num) option. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={1000}
  enumValues={null}
  examples={[1000]}
  groups={[]}
  name={"rate_limit_num"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

#### rate_limit_num

The maximum number of requests allowed within the [`rate_limit_duration_secs`](#rate_limit_duration_secs) time window. See [Rate Limits](#rate-limits) for more info.


</Field>


<Field
  common={false}
  defaultValue={-1}
  enumValues={null}
  examples={[-1]}
  groups={[]}
  name={"retry_attempts"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={null}
  >

#### retry_attempts

The maximum number of retries to make for failed requests. See [Retry Policy](#retry-policy) for more info.


</Field>


<Field
  common={false}
  defaultValue={1}
  enumValues={null}
  examples={[1]}
  groups={[]}
  name={"retry_initial_backoff_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### retry_initial_backoff_secs

The amount of time to wait before attempting the first retry for a failed request. Once, the first retry has failed the fibonacci sequence will be used to select future backoffs.


</Field>


<Field
  common={false}
  defaultValue={10}
  enumValues={null}
  examples={[10]}
  groups={[]}
  name={"retry_max_duration_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### retry_max_duration_secs

The maximum amount of time, in seconds, to wait between retries.


</Field>


<Field
  common={false}
  defaultValue={60}
  enumValues={null}
  examples={[60]}
  groups={[]}
  name={"timeout_secs"}
  path={"request"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"int"}
  unit={"seconds"}
  >

#### timeout_secs

The maximum time a request can take before being aborted. It is highly recommended that you do not lower value below the service's internal timeout, as this could create orphaned requests, pile on retries, and result in duplicate data downstream. See [Buffers & Batches](#buffers--batches) for more info.


</Field>


</Fields>

</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"resource"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### resource

Options for describing the logging resource.

<Fields filters={false}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["global","gce_instance"]}
  groups={[]}
  name={"type"}
  path={"resource"}
  relevantWhen={null}
  required={true}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### type

The monitored resource type. For example, the type of a Compute Engine VM instance is gce_instance.

See the [Google Cloud Platform monitored resource documentation][urls.gcp_resources] for more details.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[{"projectId":"vector-123456"},{"zone":"Twilight"}]}
  groups={[]}
  name={"`[label]`"}
  path={"resource"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### `[label]`

Values for all of the labels listed in the associated monitored resource descriptor.

For example, Compute Engine VM instances use the labels `projectId`, `instanceId`, and `zone`.


</Field>


</Fields>

</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={[]}
  groups={[]}
  name={"tls"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"table"}
  unit={null}
  >

### tls

Configures the TLS options for connections from this sink.

<Fields filters={false}>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/certificate_authority.crt"]}
  groups={[]}
  name={"ca_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### ca_path

Absolute path to an additional CA certificate file, in DER or PEM format (X.509).


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.crt"]}
  groups={[]}
  name={"crt_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### crt_path

Absolute path to a certificate file used to identify this connection, in DER or PEM format (X.509) or PKCS#12. If this is set and is not a PKCS#12 archive, [`key_path`](#key_path) must also be set.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["${KEY_PASS_ENV_VAR}","PassWord1"]}
  groups={[]}
  name={"key_pass"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### key_pass

Pass phrase used to unlock the encrypted key file. This has no effect unless [`key_path`](#key_path) is set.


</Field>


<Field
  common={false}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/host_certificate.key"]}
  groups={[]}
  name={"key_path"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

#### key_path

Absolute path to a certificate key file used to identify this connection, in DER or PEM format (PKCS#8). If this is set, [`crt_path`](#crt_path) must also be set.


</Field>


<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_certificate"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  >

#### verify_certificate

If `true` (the default), Vector will validate the TLS certificate of the remote host. Do NOT set this to `false` unless you understand the risks of not verifying the remote certificate.


</Field>


<Field
  common={false}
  defaultValue={true}
  enumValues={null}
  examples={[true,false]}
  groups={[]}
  name={"verify_hostname"}
  path={"tls"}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"bool"}
  unit={null}
  >

#### verify_hostname

If `true` (the default), Vector will validate the configured remote host name against the remote host's TLS certificate. Do NOT set this to `false` unless you understand the risks of not verifying the remote hostname.


</Field>


</Fields>

</Field>


</Fields>

## Env Vars

<Fields filters={true}>


<Field
  common={true}
  defaultValue={null}
  enumValues={null}
  examples={["/path/to/credentials.json"]}
  groups={[]}
  name={"GOOGLE_APPLICATION_CREDENTIALS"}
  path={null}
  relevantWhen={null}
  required={false}
  templateable={false}
  type={"string"}
  unit={null}
  >

### GOOGLE_APPLICATION_CREDENTIALS

The filename for a Google Cloud service account credentials JSON file used to authenticate access to the Stackdriver Logging API. See [GCP Authentication](#gcp-authentication) for more info.


</Field>


</Fields>

## How It Works

### Buffers & Batches

import SVG from 'react-inlinesvg';

<SVG src="/img/buffers-and-batches-serial.svg" />

The `gcp_stackdriver_logging` sink buffers & batches data as
shown in the diagram above. You'll notice that Vector treats these concepts
differently, instead of treating them as global concepts, Vector treats them
as sink specific concepts. This isolates sinks, ensuring services disruptions
are contained and [delivery guarantees][docs.guarantees] are honored.

*Batches* are flushed when 1 of 2 conditions are met:

1. The batch age meets or exceeds the configured [`timeout_secs`](#timeout_secs).
2. The batch size meets or exceeds the configured [`max_size`](#max_size).

*Buffers* are controlled via the [`buffer.*`](#buffer) options.

### Environment Variables

Environment variables are supported through all of Vector's configuration.
Simply add `${MY_ENV_VAR}` in your Vector configuration file and the variable
will be replaced before being evaluated.

You can learn more in the [Environment Variables][docs.configuration#environment-variables]
section.
### GCP Authentication

GCP offers a [variety of authentication methods][urls.gcp_authentication] and
Vector is concerned with the [server to server methods][urls.gcp_authentication_server_to_server]
and will find credentials in the following order:

1. If the [`credentials_path`](#credentials_path) option is set.
2. If the `api_key` option is set.
3. Finally, if the `GOOGLE_APPLICATION_CREDENTIALS` envrionment variable is set.

If credentials are not found the [healtcheck](#healthchecks) will fail and an
error will be [logged][docs.monitoring#logs].


### Health Checks

Health checks ensure that the downstream service is accessible and ready to
accept data. This check is performed upon sink initialization.
If the health check fails an error will be logged and Vector will proceed to
start.

#### Require Health Checks

If you'd like to exit immediately upon a health check failure, you can
pass the `--require-healthy` flag:

```bash
vector --config /etc/vector/vector.toml --require-healthy
```

#### Disable Health Checks

If you'd like to disable health checks for this sink you can set the
`healthcheck` option to `false`.

### Rate Limits

Vector offers a few levers to control the rate and volume of requests to the
downstream service. Start with the [`rate_limit_duration_secs`](#rate_limit_duration_secs) and
`rate_limit_num` options to ensure Vector does not exceed the specified
number of requests in the specified window. You can further control the pace at
which this window is saturated with the [`in_flight_limit`](#in_flight_limit) option, which
will guarantee no more than the specified number of requests are in-flight at
any given time.

Please note, Vector's defaults are carefully chosen and it should be rare that
you need to adjust these. If you found a good reason to do so please share it
with the Vector team by [opening an issie][urls.new_gcp_stackdriver_logging_sink_issue].

### Retry Policy

Vector will retry failed requests (status == `429`, >= `500`, and != `501`).
Other responses will _not_ be retried. You can control the number of retry
attempts and backoff rate with the [`retry_attempts`](#retry_attempts) and
`retry_backoff_secs` options.


[docs.configuration#environment-variables]: /docs/setup/configuration/#environment-variables
[docs.data-model.log]: /docs/about/data-model/log/
[docs.data-model]: /docs/about/data-model/
[docs.guarantees]: /docs/about/guarantees/
[docs.monitoring#logs]: /docs/administration/monitoring/#logs
[urls.gcp_authentication]: https://cloud.google.com/docs/authentication/
[urls.gcp_authentication_server_to_server]: https://cloud.google.com/docs/authentication/production
[urls.gcp_folders]: https://cloud.google.com/resource-manager/docs/creating-managing-folders
[urls.gcp_projects]: https://cloud.google.com/resource-manager/docs/creating-managing-projects
[urls.gcp_resources]: https://cloud.google.com/monitoring/api/resources
[urls.gcp_stackdriver_logging]: https://cloud.google.com/logging/docs/reference/v2/rest/
[urls.gcp_stackdriver_logging_rest]: https://cloud.google.com/logging/
[urls.new_gcp_stackdriver_logging_sink_issue]: https://github.com/timberio/vector/issues/new?labels=sink%3A+gcp_stackdriver_logging
