---
title: Install Vector via RPM
sidebar_label: RPM
description: Install Vector through the RPM package manager
---

Vector can be installed through the [RPM package manager][urls.rpm] which is
generally used on CentOS.


import Tabs from '@theme/Tabs';
import TabItem from '@theme/TabItem';

<!--
     THIS FILE IS AUTOGENERATED!

     To make changes please edit the template located at:

     website/docs/setup/installation/package-managers/rpm.md.erb
-->

## Install

<Tabs
  block={true}
  defaultValue="x86_64"
  urlKey="arch"
  values={[{"label":"x86_64","value":"x86_64"},{"label":"ARM64","value":"ARM64"},{"label":"ARMv7","value":"ARMv7"}]}>


<TabItem value="x86_64">

1.  Download the Vector `.rpm` file:

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.2)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    curl -O https://packages.timber.io/vector/0.8.X/vector-x86_64.rpm
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    curl -O https://packages.timber.io/vector/nightly/latest/vector-x86_64.rpm
    ```

    </TabItem>
    </Tabs>

2.  Install the Vector `.rpm` package directly:

    ```bash
    sudo rpm -i vector-x86_64.rpm
    ```

3.  Start Vector:

    ```bash
    sudo systemctl start vector
    ```

    That's it! Proceed to [configure](#configuring) Vector for your use case.

</TabItem>


<TabItem value="ARM64">

1.  Download the Vector `.rpm` file:

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.2)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    curl -O https://packages.timber.io/vector/0.8.X/vector-aarch64.rpm
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    curl -O https://packages.timber.io/vector/nightly/latest/vector-aarch64.rpm
    ```

    </TabItem>
    </Tabs>

2.  Install the Vector `.rpm` package directly:

    ```bash
    sudo rpm -i vector-aarch64.rpm
    ```

3.  Start Vector:

    ```bash
    sudo systemctl start vector
    ```

    That's it! Proceed to [configure](#configuring) Vector for your use case.

</TabItem>


<TabItem value="ARMv7">

1.  Download the Vector `.rpm` file:

    <Tabs
      className="mini"
      defaultValue="latest"
      values={[
        { label: 'Latest (0.8.2)', value: 'latest'},
        { label: 'Nightly', value: 'nightly'},
      ]}>

    <TabItem value="latest">

    ```bash
    curl -O https://packages.timber.io/vector/0.8.X/vector-armv7hl.rpm
    ```

    </TabItem>
    <TabItem value="nightly">

    ```bash
    curl -O https://packages.timber.io/vector/nightly/latest/vector-armv7hl.rpm
    ```

    </TabItem>
    </Tabs>

2.  Install the Vector `.rpm` package directly:

    ```bash
    sudo rpm -i vector-armv7hl.rpm
    ```

3.  Start Vector:

    ```bash
    sudo systemctl start vector
    ```

    That's it! Proceed to [configure](#configuring) Vector for your use case.

</TabItem>


</Tabs>

### Previous Versions

Historical Vector versions can be found in the [releases][urls.vector_releases].
Once you've found the version you'd like to install you can re-follow the
[install](#install) steps with the URL to the Vector `.rpm` file.

## Configuring

The Vector configuration file is placed in:

```
etc/vector/vector.toml
```

A full spec is located at `/etc/vector/vector.spec.toml` and examples are
located in `/etc/vector/examples/*`. You can learn more about configuring
Vector in the [Configuration][docs.configuration] section.

## Administering

Vector can be managed through the [Systemd][urls.systemd] service manager:

import Jump from '@site/src/components/Jump';

<Jump to="/docs/administration/">Administration</Jump>

## Uninstalling

```bash
sudo rpm -e vector
```

## Updating

Follow the [install](#install) steps again, downloading the latest version of
Vector.


[docs.configuration]: /docs/setup/configuration/
[urls.rpm]: https://rpm.org/
[urls.systemd]: https://www.freedesktop.org/wiki/Software/systemd/
[urls.vector_releases]: https://vector.dev/releases/latest
